/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.so.api.exception;

import org.ow2.petals.cli.extension.command.monitoring.so.api.SubscriptionObject;

/**
 * A subscription object exception.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class SubscriptionObjectException extends Exception {

    private static final long serialVersionUID = -8822223319042028801L;

    /**
     * The subscription object implied in the error
     */
    private final SubscriptionObject subscriptionObject;

    public SubscriptionObjectException(final SubscriptionObject subscriptionObject) {
		super();
        this.subscriptionObject = subscriptionObject;
	}

    public SubscriptionObjectException(final SubscriptionObject subscriptionObject,
            final String message,
            final Throwable cause) {
		super(message, cause);
        this.subscriptionObject = subscriptionObject;
	}

    public SubscriptionObjectException(final SubscriptionObject subscriptionObject,
            final String message) {
		super(message);
        this.subscriptionObject = subscriptionObject;
	}

    public SubscriptionObjectException(final SubscriptionObject subscriptionObject,
            final Throwable cause) {
		super(cause);
        this.subscriptionObject = subscriptionObject;
	}

    /**
     * @return The subscription object implied in the error
     */
    public SubscriptionObject getSubscriptionObject() {
        return this.subscriptionObject;
    }

}
